@@ -1,11 +1,8 @@
 from .activation import CReLU, Identity, Mish, Swish
-from .aspp import ASPP, ASPPPooling
 from .drop_connect import DropConnect
 from .focal import FocalBCELoss
-from .fpn import FPN
 from .res_block import BasicBlock, Bottleneck
 from .se_layer import SELayer
-from .spp import SPP
 from .utils import (ConvNormAct, SeparableConv, SeparableConvNormAct,
                     build_conv2d)
 from .weight_standard_conv import WSConv2d
